@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_BW_H
-#define _JOE_BW_H 1
+#ifndef JUPP_BW_H
+#define JUPP_BW_H
 
 #ifdef EXTERN_CMD_C
-__IDSTRING(rcsid_bw_h, "$MirOS: contrib/code/jupp/bw.h,v 1.8 2017/12/07 02:10:16 tg Exp $");
+__IDSTRING(rcsid_bw_h, "$MirOS: contrib/code/jupp/bw.h,v 1.9 2020/03/27 06:38:55 tg Exp $");
 #endif
 
 extern int dspasis;
