@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_RC_H
-#define _JOE_RC_H 1
+#ifndef JUPP_RC_H
+#define JUPP_RC_H
 
 #ifdef EXTERN
-__IDSTRING(rcsid_rc_h, "$MirOS: contrib/code/jupp/rc.h,v 1.12 2018/01/08 00:48:07 tg Exp $");
+__IDSTRING(rcsid_rc_h, "$MirOS: contrib/code/jupp/rc.h,v 1.14 2020/03/27 06:46:06 tg Exp $");
 #endif
 
 extern OPTIONS pdefault;
@@ -29,7 +29,7 @@ KMAP *kmap_getcontext(const unsigned char *name, int docreate);
 */
 int procrc(CAP *cap, const unsigned char *name);
 
-int glopt(unsigned char *s, unsigned char *arg, OPTIONS *options, int set);
+int glopt(const unsigned char *s, unsigned char *arg, OPTIONS *options, int set);
 
 int umode(BW *bw);
 
