@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/ufile.c,v 1.12 2017/08/08 21:39:28 tg Exp $ */
 /*
  * 	User file operations
  *	Copyright
@@ -6,23 +5,16 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
+#define EXTERN_UFILE_C
 #include "config.h"
 #include "types.h"
 
-#include <stdio.h>
-#include <unistd.h>
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-#ifdef HAVE_SYS_STAT_H
+__RCSID("$MirOS: contrib/code/jupp/ufile.c,v 1.31 2018/01/18 22:00:31 tg Exp $");
+
 #include <sys/stat.h>
-#endif
-#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
-#endif
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
+#include <unistd.h>
 
 #ifdef UTIME
 #include <utime.h>
@@ -34,10 +26,6 @@
 #endif
 #endif
 
-#ifdef WITH_SELINUX
-int copy_security_context(const char *from_file, const char *to_file);
-#endif
-
 #include "b.h"
 #include "bw.h"
 #include "macro.h"
@@ -57,12 +45,11 @@ int copy_security_context(const char *from_file, const char *to_file);
 #include "utils.h"
 #include "va.h"
 #include "vs.h"
-#include "utf8.h"
 #include "charmap.h"
 #include "w.h"
 
 extern int orphan;
-unsigned char *backpath = NULL;		/* Place to store backup files */
+unsigned char *backpath = NULL;	/* Place to store backup files */
 static B *filehist = NULL;	/* History of file names */
 int nobackups = 0;
 int exask = 0;
@@ -71,12 +58,12 @@ int exask = 0;
 /**** message which is shown after closing joe (CTRL+x; CTRL+k) *****/
 void genexmsg(BW *bw, int saved, unsigned char *name)
 {
-	unsigned char *s;
+	const unsigned char *s;
 
 	if (bw->b->name && bw->b->name[0]) {
 		s = bw->b->name;
 	} else {
-		s = US "(Unnamed)";
+		s = UC "(Unnamed)";
 	}
 
 	if (name) {
@@ -113,7 +100,8 @@ void genexmsg(BW *bw, int saved, unsigned char *name)
 }
 
 /* For ^X ^C */
-void genexmsgmulti(BW *bw, int saved, int skipped)
+static void
+genexmsgmulti(BW *bw, int saved, int skipped)
 {
 	if (saved)
 		if (skipped)
@@ -133,7 +121,7 @@ void genexmsgmulti(BW *bw, int saved, int skipped)
 int ublksave(BW *bw)
 {
 	if (markb && markk && markb->b == markk->b && (markk->byte - markb->byte) > 0 && (!square || piscol(markk) > piscol(markb))) {
-		if (wmkpw(bw->parent, US "Name of file to write (^C to abort): ", &filehist, dowrite, US "Names", NULL, cmplt, NULL, NULL, locale_map)) {
+		if (wmkpw(bw->parent, UC "Name of file to write (^C to abort): ", &filehist, dowrite, UC "Names", NULL, cmplt, NULL, NULL, locale_map)) {
 			return 0;
 		} else {
 			return -1;
@@ -156,7 +144,7 @@ int ushell(BW *bw)
 /* Copy a file */
 
 static int
-cp(unsigned char *from, int g, unsigned char *tmpfn, unsigned char *to)
+cp(const unsigned char *from, int g, const unsigned char *tmpfn, const unsigned char *to)
 {
 	int f, amnt;
 	struct stat sbuf;
@@ -169,11 +157,12 @@ cp(unsigned char *from, int g, unsigned char *tmpfn, unsigned char *to)
 #endif
 #endif
 
-	f = open((char *)from, O_RDONLY);
+	f = open((const char *)from, O_RDONLY);
 	if (f < 0) {
 		return -1;
 	}
 	if (fstat(f, &sbuf) < 0) {
+		close(f);
 		return -1;
 	}
 	if (fchmod(g, sbuf.st_mode & 0777)) {
@@ -190,6 +179,14 @@ cp(unsigned char *from, int g, unsigned char *tmpfn, unsigned char *to)
 		return -1;
 	}
 
+#ifdef HAVE_FSYNC
+	if (fsync(g))
+		return (-1);
+#endif
+
+	if (close(g))
+		return (-1);
+
 	if (tmpfn && rename(tmpfn, to)) {
 		return (-1);
 	}
@@ -198,7 +195,6 @@ cp(unsigned char *from, int g, unsigned char *tmpfn, unsigned char *to)
 	 * Below are only operations that run when the copy
 	 * process finished successfully.
 	 */
-	close(g);
 
 #ifdef HAVEUTIME
 #ifdef NeXT
@@ -211,9 +207,7 @@ cp(unsigned char *from, int g, unsigned char *tmpfn, unsigned char *to)
 	utime(to, &utbuf);
 #endif
 
-#ifdef WITH_SELINUX
 	copy_security_context(from, to);
-#endif
 
 	return 0;
 }
@@ -228,8 +222,10 @@ backup(BW *bw)
 {
 	unsigned char tmp[1024 + 12];
 	unsigned char name[1024];
-	unsigned char *simple_backup_suffix;
+	const unsigned char *simple_backup_suffix;
+	unsigned char *tmpfn;
 	int fd;
+	int rv;
 
 	if (bw->b->backup || nobackups || !(bw->b->name) || !(bw->b->name[0]))
 		return (0);
@@ -238,7 +234,7 @@ backup(BW *bw)
 	simple_backup_suffix = (unsigned char *)getenv("SIMPLE_BACKUP_SUFFIX");
 
 	if (simple_backup_suffix == NULL) {
-		simple_backup_suffix = US "~";
+		simple_backup_suffix = UC "~";
 	}
 	if (backpath) {
 		joe_snprintf_3((char *)name, sizeof(name), "%s/%s%s", backpath, namepart(tmp, bw->b->name), simple_backup_suffix);
@@ -257,21 +253,24 @@ backup(BW *bw)
 	if (strlcat((char *)tmp, (char *)name, sizeof(tmp)) >= sizeof(tmp))
 		return (1);
 	*(dirprt_ptr(tmp)) = '\0';
-	if ((simple_backup_suffix = mktmp(tmp, &fd)) == NULL)
+	if ((tmpfn = mktmp(tmp, &fd)) == NULL)
 		return (1);
 
 	/* Attempt to delete backup file first */
 	unlink((char *)name);
 
 	/* Copy original file to backup file securely */
-	if (cp(bw->b->name, fd, simple_backup_suffix, name)) {
+	if (cp(bw->b->name, fd, tmpfn, name)) {
 		close(fd);
-		unlink((char *)simple_backup_suffix);
-		return (1);
+		unlink((char *)tmpfn);
+		rv = 1;
+	} else {
+		bw->b->backup = 1;
+		rv = 0;
 	}
 
-	bw->b->backup = 1;
-	return (0);
+	vsrm(tmpfn);
+	return (rv);
 }
 
 /* Write file */
@@ -279,35 +278,38 @@ backup(BW *bw)
 /* Continuation structure */
 
 struct savereq {
-	int (*callback) ();
+	int (*callback)(BW *, struct savereq *, int, int *);
 	unsigned char *name;
 	B *first;
 	int not_saved;	/* Set if a modified file was not saved */
 	int rename;	/* Set if we're renaming the file during save */
 };
 
-struct savereq *mksavereq(int (*callback)(), unsigned char *name, B *first,int rename_)
+static struct savereq *
+mksavereq(int (*callback)(BW *, struct savereq *, int, int *),
+    unsigned char *name, B *first, int dorename)
 {
-	struct savereq *req = (struct savereq *) joe_malloc(sizeof(struct savereq));
+	struct savereq *req = malloc(sizeof(struct savereq));
+
 	req->callback = callback;
 	req->name = name;
 	req->first = first;
 	req->not_saved = 0;
-	req->rename = rename_;
+	req->rename = dorename;
 	return req;
 }
 
 static void rmsavereq(struct savereq *req)
 {
 	vsrm(req->name);
-	joe_free(req);
+	free(req);
 }
 
 static int saver(BW *bw, int c, struct savereq *req, int *notify)
 {
 	int fl;
-	if (c == 'n' || c == 'N') {
-		msgnw(bw->parent, US "Couldn't make backup file... file not saved");
+	if ((c | 0x20) == 'n') {
+		msgnw(bw->parent, UC "Couldn't make backup file... file not saved");
 		if (req->callback) {
 			return req->callback(bw, req, -1, notify);
 		} else {
@@ -318,7 +320,7 @@ static int saver(BW *bw, int c, struct savereq *req, int *notify)
 			return -1;
 		}
 	}
-	if (c != 'y' && c != 'Y') {
+	if ((c | 0x20) != 'y') {
 		if (mkqw(bw->parent, sc("Could not make backup file.  Save anyway (y,n,^C)? "), saver, NULL, req, notify)) {
 			return 0;
 		} else {
@@ -348,7 +350,7 @@ static int saver(BW *bw, int c, struct savereq *req, int *notify)
 		}
 	} else {
 		if (req->rename) {
-			joe_free(bw->b->name);
+			free(bw->b->name);
 			bw->b->name = 0;
 		}
 		if (!bw->b->name)
@@ -386,20 +388,17 @@ static int saver(BW *bw, int c, struct savereq *req, int *notify)
 	}
 }
 
-static int dosave(BW *bw, struct savereq *req, int *notify)
+static int
+dosave(BW *bw, struct savereq *req, int *notify)
 {
-	if (backup(bw)) {
-		return saver(bw, 0, req, notify);
-	} else {
-		return saver(bw, 'y', req, notify);
-	}
+	return (saver(bw, backup(bw) ? 0 : 'y', req, notify));
 }
 
 static int dosave2(BW *bw, int c, struct savereq *req, int *notify)
 {
-	if (c == 'y' || c == 'Y') {
+	if ((c | 0x20) == 'y') {
 		return dosave(bw, req, notify);
-	} else if (c == 'n' || c == 'N') {
+	} else if ((c | 0x20) == 'n') {
 		if (notify) {
 			*notify = 1;
 		}
@@ -417,9 +416,9 @@ static int dosave2(BW *bw, int c, struct savereq *req, int *notify)
 
 static int dosave2a(BW *bw, int c, struct savereq *req, int *notify)
 {
-	if (c == 'y' || c == 'Y') {
+	if ((c | 0x20) == 'y') {
 		return dosave(bw, req, notify);
-	} else if (c == 'n' || c == 'N') {
+	} else if ((c | 0x20) == 'n') {
 		if (notify) {
 			*notify = 1;
 		}
@@ -474,7 +473,7 @@ int usave(BW *bw)
 {
 	BW *pbw;
 
-	pbw = wmkpw(bw->parent, US "Name of file to save (^C to abort): ", &filehist, dosave1, US "Names", NULL, cmplt, mksavereq(NULL,NULL,NULL,0), NULL, locale_map);
+	pbw = wmkpw(bw->parent, UC "Name of file to save (^C to abort): ", &filehist, dosave1, UC "Names", NULL, cmplt, mksavereq(NULL,NULL,NULL,0), NULL, locale_map);
 
 	if (pbw && bw->b->name) {
 		binss(pbw->cursor, bw->b->name);
@@ -490,105 +489,73 @@ int usave(BW *bw)
 
 /* Load file to edit */
 
-int doedit1(BW *bw,int c,unsigned char *s,int *notify)
+static int
+doedit1(BW *bw, int c, unsigned char *s, int *notify)
 {
 	int ret = 0;
 	int er;
 	void *object;
 	W *w;
 	B *b;
-	if (c=='y' || c=='Y') {
+
+	switch (c | 0x20) {
+	case 'y':
 		/* Reload from file */
-
-		if (notify) {
-			*notify = 1;
-		}
-
-		b = bfind_reload(s);
-		er = error;
-		if (bw->b->count >= 1 && (bw->b->changed || bw->b->name)) {
-			if (orphan) {
-				orphit(bw);
-			} else {
-				if (uduptw(bw)) {
-					brm(b);
-					return -1;
-				}
-				bw = (BW *) maint->curwin->object;
-			}
-		}
-		if (er) {
-			msgnwt(bw->parent, msgs[-er]);
-			if (er != -1) {
-				ret = -1;
-			}
-		}
-		object = bw->object;
-		w = bw->parent;
-		bwrm(bw);
-		w->object = (void *) (bw = bwmk(w, b, 0));
-		wredraw(bw->parent);
-		bw->object = object;
-		vsrm(s);
-		if (er == -1 && bw->o.mnew) {
-			exemac(bw->o.mnew);
-		}
-		if (er == 0 && bw->o.mold) {
-			exemac(bw->o.mold);
-		}
-		return ret;
-	} else if(c=='n' || c=='N') {
+		c = 1;
+		break;
+	case 'n':
 		/* Edit already loaded buffer */
-
-		if (notify) {
-			*notify = 1;
-		}
-
-		b = bfind(s);
-		er = error;
-		if (bw->b->count == 1 && (bw->b->changed || bw->b->name)) {
-			if (orphan) {
-				orphit(bw);
-			} else {
-				if (uduptw(bw)) {
-					brm(b);
-					return -1;
-				}
-				bw = (BW *) maint->curwin->object;
-			}
-		}
-		if (er) {
-			msgnwt(bw->parent, msgs[-er]);
-			if (er != -1) {
-				ret = -1;
-			}
-		}
-		object = bw->object;
-		w = bw->parent;
-		bwrm(bw);
-		w->object = (void *) (bw = bwmk(w, b, 0));
-		wredraw(bw->parent);
-		bw->object = object;
-		vsrm(s);
-		if (er == -1 && bw->o.mnew) {
-			exemac(bw->o.mnew);
-		}
-		if (er == 0 && bw->o.mold) {
-			exemac(bw->o.mold);
-		}
-		return ret;
-	} else {
+		c = 0;
+		break;
+	default:
+		/* Ask what todo */
 		/* FIXME: need abort handler to prevent leak */
 		if (mkqw(bw->parent, sc("Load original file from disk (y,n,^C)? "), doedit1, NULL, s, notify))
-			return 0;
-		else {
-			vsrm(s);
-			return -1;
+			return (0);
+		vsrm(s);
+		return (-1);
+	}
+
+	if (notify)
+		*notify = 1;
+
+	b = c ? bfind_reload(s) : bfind(s);
+	er = error;
+	c = c ? (bw->b->count >= 1) : (bw->b->count == 1);
+
+	if (c && (bw->b->changed || bw->b->name)) {
+		if (orphan) {
+			orphit(bw);
+		} else {
+			if (uduptw(bw)) {
+				brm(b);
+				vsrm(s);
+				return (-1);
+			}
+			bw = maint->curwin->object.bw;
 		}
 	}
+	if (er) {
+		msgnwt(bw->parent, msgs[-er]);
+		if (er != -1)
+			ret = -1;
+	}
+	object = bw->object;
+	w = bw->parent;
+	bwrm(bw);
+	w->object.bw = bw = bwmk(w, b, 0);
+	wredraw(bw->parent);
+	bw->object = object;
+	vsrm(s);
+	if (er == -1 && bw->o.mnew)
+		exemac(bw->o.mnew);
+	if (er == 0 && bw->o.mold)
+		exemac(bw->o.mold);
+	return (ret);
 }
 
-int doedit(BW *bw, unsigned char *s, void *obj, int *notify)
+static int
+doedit(BW *bw, unsigned char *s, void *obj, int *notify)
 {
 	B *b;
 
@@ -609,7 +576,7 @@ int doedit(BW *bw, unsigned char *s, void *obj, int *notify)
 int okrepl(BW *bw)
 {
 	if (bw->b->count == 1 && bw->b->changed) {
-		msgnw(bw->parent, US "Can't replace modified file");
+		msgnw(bw->parent, UC "Can't replace modified file");
 		return -1;
 	} else {
 		return 0;
@@ -618,7 +585,7 @@ int okrepl(BW *bw)
 
 int uedit(BW *bw)
 {
-	if (wmkpw(bw->parent, US "Name of file to edit (^C to abort): ", &filehist, doedit, US "Names", NULL, cmplt, NULL, NULL, locale_map)) {
+	if (wmkpw(bw->parent, UC "Name of file to edit (^C to abort): ", &filehist, doedit, UC "Names", NULL, cmplt, NULL, NULL, locale_map)) {
 		return 0;
 	} else {
 		return -1;
@@ -633,14 +600,15 @@ int doswitch(BW *bw, unsigned char *s, void *obj, int *notify)
 
 int uswitch(BW *bw)
 {
-	if (wmkpw(bw->parent, US "Name of buffer to edit (^C to abort): ", &filehist, doswitch, US "Names", NULL, cmplt, NULL, NULL, locale_map)) {
+	if (wmkpw(bw->parent, UC "Name of buffer to edit (^C to abort): ", &filehist, doswitch, UC "Names", NULL, cmplt, NULL, NULL, locale_map)) {
 		return 0;
 	} else {
 		return -1;
 	}
 }
 
-int doscratch(BW *bw, unsigned char *s, void *obj, int *notify)
+static int
+doscratch(BW *bw, unsigned char *s, void *obj, int *notify)
 {
 	int ret = 0;
 	int er;
@@ -654,6 +622,7 @@ int doscratch(BW *bw, unsigned char *s, void *obj, int *notify)
 
 	b = bfind_scratch(s);
 	er = error;
+	vsrm(s);
 	if (bw->b->count == 1 && (bw->b->changed || bw->b->name)) {
 		if (orphan) {
 			orphit(bw);
@@ -662,7 +631,7 @@ int doscratch(BW *bw, unsigned char *s, void *obj, int *notify)
 				brm(b);
 				return -1;
 			}
-			bw = (BW *) maint->curwin->object;
+			bw = maint->curwin->object.bw;
 		}
 	}
 	if (er && er != -1) {
@@ -672,10 +641,9 @@ int doscratch(BW *bw, unsigned char *s, void *obj, int *notify)
 	object = bw->object;
 	w = bw->parent;
 	bwrm(bw);
-	w->object = (void *) (bw = bwmk(w, b, 0));
+	w->object.bw = bw = bwmk(w, b, 0);
 	wredraw(bw->parent);
 	bw->object = object;
-	vsrm(s);
 	if (er == -1 && bw->o.mnew) {
 		exemac(bw->o.mnew);
 	}
@@ -687,7 +655,7 @@ int doscratch(BW *bw, unsigned char *s, void *obj, int *notify)
 
 int uscratch(BW *bw)
 {
-	if (wmkpw(bw->parent, US "Name of scratch buffer to edit (^C to abort): ", &filehist, doscratch, US "Names", NULL, cmplt, NULL, NULL, locale_map)) {
+	if (wmkpw(bw->parent, UC "Name of scratch buffer to edit (^C to abort): ", &filehist, doscratch, UC "Names", NULL, cmplt, NULL, NULL, locale_map)) {
 		return 0;
 	} else {
 		return -1;
@@ -719,7 +687,7 @@ static int dorepl(BW *bw, unsigned char *s, void *obj, int *notify)
 		orphit(bw);
 	}
 	bwrm(bw);
-	w->object = (void *) (bw = bwmk(w, b, 0));
+	w->object.bw = bw = bwmk(w, b, 0);
 	wredraw(bw->parent);
 	bw->object = object;
 	vsrm(s);
@@ -756,7 +724,7 @@ int unbuf(BW *bw)
 		orphit(bw);
 	}
 	bwrm(bw);
-	w->object = (void *) (bw = bwmk(w, b, 0));
+	w->object.bw = bw = bwmk(w, b, 0);
 	wredraw(bw->parent);
 	bw->object = object;
 	return 0;
@@ -784,7 +752,7 @@ int upbuf(BW *bw)
 		orphit(bw);
 	}
 	bwrm(bw);
-	w->object = (void *) (bw = bwmk(w, b, 0));
+	w->object.bw = bw = bwmk(w, b, 0);
 	wredraw(bw->parent);
 	bw->object = object;
 	return 0;
@@ -792,7 +760,7 @@ int upbuf(BW *bw)
 
 int uinsf(BW *bw)
 {
-	if (wmkpw(bw->parent, US "Name of file to insert (^C to abort): ", &filehist, doinsf, US "Names", NULL, cmplt, NULL, NULL, locale_map)) {
+	if (wmkpw(bw->parent, UC "Name of file to insert (^C to abort): ", &filehist, doinsf, UC "Names", NULL, cmplt, NULL, NULL, locale_map)) {
 		return 0;
 	} else {
 		return -1;
@@ -825,7 +793,7 @@ int uexsve(BW *bw)
 		/* It changed, it's not a scratch buffer and it's named */
 		return dosave1(bw, vsncpy(NULL, 0, sz(bw->b->name)), mksavereq(exdone,NULL,NULL,0), NULL);
 	} else {
-		BW *pbw = wmkpw(bw->parent, US "Name of file to save (^C to abort): ", &filehist, dosave1, US "Names", NULL, cmplt, mksavereq(exdone,NULL,NULL,1), NULL, locale_map);
+		BW *pbw = wmkpw(bw->parent, UC "Name of file to save (^C to abort): ", &filehist, dosave1, UC "Names", NULL, cmplt, mksavereq(exdone,NULL,NULL,1), NULL, locale_map);
 
 		if (pbw && bw->b->name) {
 			binss(pbw->cursor, bw->b->name);
@@ -845,12 +813,12 @@ int uexsve(BW *bw)
 
 static int nask(BW *bw, int c, void *object, int *notify)
 {
-	if (c == 'y' || c == 'Y') {
+	if ((c | 0x20) == 'y') {
 		/* uexsve macro should be here... */
 		if(notify)
 			*notify = 1;
 		return 0;
-	} else if (c == 'n' || c == 'N') {
+	} else if ((c | 0x20) == 'n') {
 		if(notify)
 			*notify = -1;
 		genexmsg(bw, 0, NULL);
@@ -887,7 +855,7 @@ static int dolose(BW *bw, int c, void *object, int *notify)
 	if (notify) {
 		*notify = 1;
 	}
-	if (c != 'y' && c != 'Y') {
+	if ((c | 0x20) != 'y') {
 		return -1;
 	}
 
@@ -899,26 +867,26 @@ static int dolose(BW *bw, int c, void *object, int *notify)
 
 	if ((w = maint->topwin) != NULL) {
 		do {
-			if ((w->watom->what&TYPETW) && ((BW *)w->object)->b==b) {
+			if ((w->watom->what & TYPETW) && w->object.bw->b == b) {
 				if ((new_b = borphan()) != NULL) {
-					BW *bw_ = (BW *)w->object;
-					void *object_ = bw_->object;
+					BW *bw2 = w->object.bw;
+					void *object_ = bw2->object;
 					/* FIXME: Shouldn't we wabort() and wcreate here to kill
 					   any prompt windows? */
 
-					bwrm(bw_);
-					w->object = (void *) (bw_ = bwmk(w, new_b, 0));
+					bwrm(bw2);
+					w->object.bw = bw2 = bwmk(w, new_b, 0);
 					wredraw(w);
-					bw_->object = object_;
+					bw2->object = object_;
 				} else {
-					BW *bw_ = (BW *)w->object;
-					object = bw_->object;
-					bwrm(bw_);
-					w->object = (void *) (bw_ = bwmk(w, bfind(US ""), 0));
+					BW *bw2 = w->object.bw;
+					object = bw2->object;
+					bwrm(bw2);
+					w->object.bw = bw2 = bwmk(w, bfind(UC ""), 0);
 					wredraw(w);
-					bw_->object = object;
-					if (bw_->o.mnew)
-						exemac(bw_->o.mnew);
+					bw2->object = object;
+					if (bw2->o.mnew)
+						exemac(bw2->o.mnew);
 				}
 			}
 		w = w->link.next;
@@ -949,7 +917,7 @@ int ulose(BW *bw)
 static int dobuf(MENU *m, int x, unsigned char **s)
 {
 	unsigned char *name;
-	BW *bw = m->parent->win->object;
+	BW *bw = m->parent->win->object.bw;
 	int *notify = m->parent->notify;
 
 	m->parent->notify = 0;
@@ -982,37 +950,40 @@ int ubufed(BW *bw)
 static int doquerysave(BW *bw,int c,struct savereq *req,int *notify)
 {
 	W *w = bw->parent;
-	if (c == 'y' || c == 'Y') {
+
+	if ((c | 0x20) == 'y') {
 		if (bw->b->name && bw->b->name[0])
 			return dosave1(bw, vsncpy(NULL,0,sz(bw->b->name)), req, notify);
 		else {
 			BW *pbw;
-			pbw = wmkpw(bw->parent, US "Name of file to save (^C to abort): ", &filehist, dosave1, US "Names", NULL, cmplt, req, notify, locale_map);
+			pbw = wmkpw(bw->parent, UC "Name of file to save (^C to abort): ", &filehist, dosave1, UC "Names", NULL, cmplt, req, notify, locale_map);
 
 			if (pbw) {
 				return 0;
 			} else {
-				joe_free(req);
+				free(req);
 				return -1;
 			}
 		}
-	} else if (c == 'n' || c == 'N') {
+	} else if ((c | 0x20) == 'n') {
 		/* Find next buffer to save */
 		if (bw->b->changed)
 			req->not_saved = 1;
-		next:
+ next:
 		if (unbuf(bw)) {
 			if (notify)
 				*notify = 1;
 			rmsavereq(req);
 			return -1;
 		}
-		bw = w->object;
+		bw = w->object.bw;
 		if (bw->b==req->first) {
+			int cached_not_saved = req->not_saved;
+
 			if (notify)
 				*notify = 1;
 			rmsavereq(req);
-			genexmsgmulti(bw,1,req->not_saved);
+			genexmsgmulti(bw,1,cached_not_saved);
 			return 0;
 		}
 		if (!bw->b->changed || bw->b->scratch)
@@ -1021,10 +992,10 @@ static int doquerysave(BW *bw,int c,struct savereq *req,int *notify)
 		return doquerysave(bw,0,req,notify);
 	} else {
 		unsigned char buf[1024];
-		joe_snprintf_1(buf,1024,"File %s has been modified.  Save it (y,n,^C)? ",bw->b->name ? bw->b->name : US "(Unnamed)" );
+		joe_snprintf_1(buf,1024,"File %s has been modified.  Save it (y,n,^C)? ",bw->b->name ? bw->b->name : UC "(Unnamed)" );
 		if (mkqw(bw->parent, sz(buf), doquerysave, NULL, req, notify)) {
 			return 0;
-			} else {
+		} else {
 			/* Should be in abort function */
 			rmsavereq(req);
 			return -1;
@@ -1054,7 +1025,7 @@ int uquerysave(BW *bw)
 			return doquerysave(bw,0,mksavereq(query_next,NULL,first,0),NULL);
 		else if (unbuf(bw))
 			return -1;
-		bw = w->object;
+		bw = w->object.bw;
 	} while(bw->b!=first);
 
 	genexmsgmulti(bw,0,0);
@@ -1076,3 +1047,21 @@ uabendjoe(BW *bw)
 	main_rv = 1;
 	return (ukilljoe(bw));
 }
+
+int
+usync(BW *bw)
+{
+#ifdef HAVE_SYNC
+	msgnwt(bw->parent, UC "\\i>\\i \\fSynchronising, please wait...\\f \\i<\\i");
+	msgout(bw->parent);
+	edupd(1);
+	sync();
+	sleep(1);
+	sync();
+	msgnwt(bw->parent, UC "\\i>\\i \\bSynchronised buffers to disc.\\b \\i<\\i");
+	return (0);
+#else
+	msgnw(bw->parent, UC "Sorry, compiled without sync(2)");
+	return (-1);
+#endif
+}
