@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_UMATH_H
-#define _JOE_UMATH_H 1
+#ifndef JUPP_UMATH_H
+#define JUPP_UMATH_H
 
 #ifdef EXTERN_CMD_C
-__IDSTRING(rcsid_umath_h, "$MirOS: contrib/code/jupp/umath.h,v 1.11 2017/12/06 21:17:03 tg Exp $");
+__IDSTRING(rcsid_umath_h, "$MirOS: contrib/code/jupp/umath.h,v 1.12 2020/03/27 06:38:59 tg Exp $");
 #endif
 
 #include <signal.h>
