@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/ushell.c,v 1.4 2012/12/30 18:18:07 tg Exp $ */
 /*
  *	Shell-window functions
  *	Copyright
@@ -9,19 +8,12 @@
 #include "config.h"
 #include "types.h"
 
-#include <unistd.h>
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-#ifdef HAVE_SYS_STAT_H
+__RCSID("$MirOS: contrib/code/jupp/ushell.c,v 1.15 2017/12/08 03:24:16 tg Exp $");
+
 #include <sys/stat.h>
-#endif
-#ifdef HAVE_SIGNAL_H
 #include <signal.h>
-#endif
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
+#include <unistd.h>
 
 #include "b.h"
 #include "main.h"
@@ -39,6 +31,7 @@
 
 extern int orphan;
 
+#if WANT_FORK
 /* Executed when shell process terminates */
 
 static void cdone(B *b)
@@ -61,16 +54,18 @@ static void cdone_parse(B *b)
 static void cfollow(B *b,long byte)
 {
 	W *w;
-	 if ((w = maint->topwin) != NULL) {
-	 	do {
-	 		if ((w->watom->what&TYPETW) && ((BW *)w->object)->b==b && ((BW *)w->object)->cursor->byte==byte) {
-	 			BW *bw = (BW *)w->object;
-	 			p_goto_eof(bw->cursor);
+	if ((w = maint->topwin) != NULL) {
+		do {
+			if ((w->watom->what & TYPETW) &&
+			    w->object.bw->b == b &&
+			    w->object.bw->cursor->byte == byte) {
+				BW *bw = w->object.bw;
+				p_goto_eof(bw->cursor);
 				bw->cursor->xcol = piscol(bw->cursor);
-	 		}
-		w = w->link.next;
-	 	} while (w != maint->topwin);
-	 }
+			}
+			w = w->link.next;
+		} while (w != maint->topwin);
+	}
 }
 
 static void cdata(B *b, unsigned char *dat, int siz)
@@ -110,14 +105,6 @@ static void cdata(B *b, unsigned char *dat, int siz)
 
 static int doushell(BW *bw, unsigned char *cmd, int *notify, int build)
 {
-#ifdef __MSDOS__
-	if (notify) {
-		*notify = 1;
-	}
-	varm(s);
-	msgnw(bw->parent, "Sorry, no sub-processes in DOS (yet)");
-	return -1;
-#else
 	MPX *m;
 	unsigned char **s;
 	unsigned char *u;
@@ -140,28 +127,31 @@ static int doushell(BW *bw, unsigned char *cmd, int *notify, int build)
 		*notify = 1;
 	}
 	if (bw->b->pid) {
-		msgnw(bw->parent, US "Program already running in this window");
+		msgnw(bw->parent, UC "Program already running in this window");
 		varm(s);
+		vsrm(cmd);
 		return -1;
 	}
 	p_goto_eof(bw->cursor);
 
 	if (!(m = mpxmk(&bw->b->out, name, s, cdata, bw->b, build ? cdone_parse : cdone, bw->b))) {
 		varm(s);
-		msgnw(bw->parent, US "No ptys available");
+		vsrm(cmd);
+		msgnw(bw->parent, UC "No ptys available");
 		return -1;
 	} else {
 		bw->b->pid = m->pid;
 	}
+	varm(s);
+	vsrm(cmd);
 	return 0;
-#endif
 }
 
 int ubknd(BW *bw)
 {
 	if (!getenv("SHELL")) {
-        	msgnw(bw->parent, US "\"SHELL\" environment variable not defined or exported");
-        }
+		msgnw(bw->parent, UC "\"SHELL\" environment variable not defined or exported");
+	}
 	return doushell(bw, NULL, NULL, 0);
 }
 
@@ -176,7 +166,7 @@ B *runhist = NULL;
 
 int urun(BW *bw)
 {
-	if (wmkpw(bw->parent, US "Program to run: ", &runhist, dorun, US "Run", NULL, NULL, NULL, NULL, locale_map)) {
+	if (wmkpw(bw->parent, UC "Program to run: ", &runhist, dorun, UC "Run", NULL, NULL, NULL, NULL, locale_map)) {
 		return 0;
 	} else {
 		return -1;
@@ -193,16 +183,17 @@ B *buildhist = NULL;
 int ubuild(BW *bw)
 {
 	if (buildhist) {
-		if ((bw=wmkpw(bw->parent, US "Build command: ", &buildhist, dobuild, US "Run", NULL, NULL, NULL, NULL, locale_map))) {
+		if ((bw=wmkpw(bw->parent, UC "Build command: ", &buildhist, dobuild, UC "Run", NULL, NULL, NULL, NULL, locale_map))) {
 			uuparw(bw);
 			u_goto_eol(bw);
 			bw->cursor->xcol = piscol(bw->cursor);
 			return 0;
 		}
-	} else if (wmkpw(bw->parent, US "Enter build command (for example, 'make'): ", &buildhist, dobuild, US "Run", NULL, NULL, NULL, NULL, locale_map))
+	} else if (wmkpw(bw->parent, UC "Enter build command (for example, 'make'): ", &buildhist, dobuild, UC "Run", NULL, NULL, NULL, NULL, locale_map))
 			return 0;
 		return -1;
 }
+#endif
 
 /* Kill program */
 
@@ -211,7 +202,7 @@ static int pidabort(BW *bw, int c, void *object, int *notify)
 	if (notify) {
 		*notify = 1;
 	}
-	if (c != 'y' && c != 'Y') {
+	if ((c | 0x20) != 'y') {
 		return -1;
 	}
 	if (bw->b->pid) {
