@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/utag.c,v 1.3 2017/08/09 00:46:02 tg Exp $ */
 /*
  *	tags file symbol lookup
  *	Copyright
@@ -9,7 +8,7 @@
 #include "config.h"
 #include "types.h"
 
-#include <stdio.h>
+__RCSID("$MirOS: contrib/code/jupp/utag.c,v 1.11 2017/12/07 02:10:19 tg Exp $");
 
 #include "b.h"
 #include "bw.h"
@@ -18,9 +17,9 @@
 #include "tab.h"
 #include "ufile.h"
 #include "usearch.h"
+#include "utag.h"
 #include "utils.h"
 #include "vs.h"
-#include "utf8.h"
 #include "charmap.h"
 #include "w.h"
 
@@ -40,7 +39,7 @@ static int dotag(BW *bw, unsigned char *s, void *obj, int *notify)
 	}
 	f = fopen("tags", "r");
 	if (!f) {
-		msgnw(bw->parent, US "Couldn't open tags file");
+		msgnw(bw->parent, UC "Couldn't open tags file");
 		vsrm(s);
 		vsrm(t);
 		return -1;
@@ -66,7 +65,7 @@ static int dotag(BW *bw, unsigned char *s, void *obj, int *notify)
 					fclose(f);
 					return -1;
 				}
-				bw = (BW *) maint->curwin->object;
+				bw = maint->curwin->object.bw;
 				buf[y] = c;
 				while (buf[y] == ' ' || buf[y] == '\t') {
 					++y;
@@ -77,7 +76,7 @@ static int dotag(BW *bw, unsigned char *s, void *obj, int *notify)
 					long line = 0;
 
 					if (buf[y] >= '0' && buf[y] <= '9') {
-						sscanf((char *)(buf + y), "%ld", &line);
+						line = ustol(buf + y, NULL, USTOL_AUTO);
 						if (line >= 1) {
 							int omid = mid;
 
@@ -86,7 +85,7 @@ static int dotag(BW *bw, unsigned char *s, void *obj, int *notify)
 							dofollows();
 							mid = omid;
 						} else {
-							msgnw(bw->parent, US "Invalid line number");
+							msgnw(bw->parent, UC "Invalid line number");
 						}
 					} else {
 						if (buf[y] == '/' || buf[y] == '?') {
@@ -120,7 +119,7 @@ static int dotag(BW *bw, unsigned char *s, void *obj, int *notify)
 			}
 		}
 	}
-	msgnw(bw->parent, US "Not found");
+	msgnw(bw->parent, UC "Not found");
 	vsrm(s);
 	vsrm(t);
 	fclose(f);
@@ -133,19 +132,19 @@ int utag(BW *bw)
 {
 	BW *pbw;
 
-	pbw = wmkpw(bw->parent, US "Tag search: ", &taghist, dotag, NULL, NULL, cmplt, NULL, NULL, locale_map);
-	if (pbw && joe_isalnum_(bw->b->o.charmap,brch(bw->cursor))) {
+	pbw = wmkpw(bw->parent, UC "Tag search: ", &taghist, dotag, NULL, NULL, cmplt, NULL, NULL, locale_map);
+	if (pbw && joe_isalnux(bw->b->o.charmap,brch(bw->cursor))) {
 		P *p = pdup(bw->cursor);
 		P *q = pdup(p);
 		int c;
 
-		while (joe_isalnum_(bw->b->o.charmap,(c = prgetc(p))))
+		while (joe_isalnux(bw->b->o.charmap,(c = prgetc(p))))
 			/* do nothing */;
 		if (c != NO_MORE_DATA) {
 			pgetc(p);
 		}
 		pset(q, p);
-		while (joe_isalnum_(bw->b->o.charmap,(c = pgetc(q))))
+		while (joe_isalnux(bw->b->o.charmap,(c = pgetc(q))))
 			/* do nothing */;
 		if (c != NO_MORE_DATA) {
 			prgetc(q);
