@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_W_H
-#define _JOE_W_H 1
+#ifndef JUPP_W_H
+#define JUPP_W_H
 
 #ifdef EXTERN
-__IDSTRING(rcsid_w_h, "$MirOS: contrib/code/jupp/w.h,v 1.9 2017/12/07 02:10:20 tg Exp $");
+__IDSTRING(rcsid_w_h, "$MirOS: contrib/code/jupp/w.h,v 1.11 2020/03/27 06:39:01 tg Exp $");
 #endif
 
 /***************/
@@ -155,7 +155,7 @@ void msgout(W *w);			/* Output msgnw/msgnwt messages */
 
 /* Common user functions */
 
-int urtn(jobject jO, int k);		/* User hit return */
+int urtn(jobject jO);			/* User hit return */
 int utype(jobject jO, int k);		/* User types a character */
 int uretyp(BASE *bw);			/* Refresh the screen */
 int ugroww(BASE *bw);			/* Grow current window */
